==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/ButtonBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ButtonBaseType_$type } from "./ButtonBaseType";
import { ButtonBaseTarget_$type } from "./ButtonBaseTarget";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var ButtonBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ButtonBase, _super);
    function ButtonBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.clicked = null;
        _this.g = new WCNativeHelper();
        _this.j = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    ButtonBase.prototype.clickedChanged = function () {
        var _this = this;
        if (this.clicked != null) {
            this.h.q("click", function (a) { return _this.clicked(_this, VoidEventArgs.b(a)); }, false);
        }
        else {
            this.h.t("click");
        }
    };
    Object.defineProperty(ButtonBase.prototype, "h", {
        get: function () {
            return this.g;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "nativeElement", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g.n = this.j;
        },
        enumerable: false,
        configurable: true
    });
    ButtonBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(ButtonBase.prototype, "b", {
        get: function () {
            var ret_ = this.h.m("type");
            ret_ = enumGetBox(ButtonBaseType_$type, EnumUtil.getEnumValue(ButtonBaseType_$type, this.h.f(ButtonBaseType_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonBaseType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.h.u("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "n", {
        get: function () {
            var ret_ = this.h.m("href");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.u("href", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "m", {
        get: function () {
            var ret_ = this.h.m("download");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.u("download", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "a", {
        get: function () {
            var ret_ = this.h.m("target");
            ret_ = enumGetBox(ButtonBaseTarget_$type, EnumUtil.getEnumValue(ButtonBaseTarget_$type, this.h.f(ButtonBaseTarget_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseTarget_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonBaseTarget_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.h.u("target", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "o", {
        get: function () {
            var ret_ = this.h.m("rel");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.u("rel", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "i", {
        get: function () {
            var ret_ = this.h.m("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.u("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "l", {
        get: function () {
            var ret_ = this.h.m("ariaLabel");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.u("ariaLabel", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "c", {
        get: function () {
            var ret_ = this.h.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.h.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.h.u("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    ButtonBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.h.q("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.h.t("focus");
        }
    };
    ButtonBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.h.q("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.h.t("blur");
        }
    };
    ButtonBase.prototype.t = function (a) {
        this.nativeElement.focus(this.h.h(a));
    };
    ButtonBase.prototype.q = function () {
        this.nativeElement.blur();
    };
    ButtonBase.$t = markType(ButtonBase, 'ButtonBase', BaseElement.$);
    return ButtonBase;
}(BaseElement));
export { ButtonBase };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/ButtonBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ButtonBaseType_$type } from "./ButtonBaseType";
import { ButtonBaseTarget_$type } from "./ButtonBaseTarget";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var ButtonBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ButtonBase, _super);
    function ButtonBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.clicked = null;
        _this.g = new WCNativeHelper();
        _this.j = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    ButtonBase.prototype.clickedChanged = function () {
        var _this = this;
        if (this.clicked != null) {
            this.h.r("click", function (a) { return _this.clicked(_this, VoidEventArgs.b(a)); }, false);
        }
        else {
            this.h.u("click");
        }
    };
    Object.defineProperty(ButtonBase.prototype, "h", {
        get: function () {
            return this.g;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "nativeElement", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g.o = this.j;
        },
        enumerable: false,
        configurable: true
    });
    ButtonBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(ButtonBase.prototype, "b", {
        get: function () {
            var ret_ = this.h.n("type");
            ret_ = enumGetBox(ButtonBaseType_$type, EnumUtil.getEnumValue(ButtonBaseType_$type, this.h.f(ButtonBaseType_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonBaseType_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.h.v("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "n", {
        get: function () {
            var ret_ = this.h.n("href");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("href", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "m", {
        get: function () {
            var ret_ = this.h.n("download");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("download", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "a", {
        get: function () {
            var ret_ = this.h.n("target");
            ret_ = enumGetBox(ButtonBaseTarget_$type, EnumUtil.getEnumValue(ButtonBaseTarget_$type, this.h.f(ButtonBaseTarget_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseTarget_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonBaseTarget_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.h.v("target", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "o", {
        get: function () {
            var ret_ = this.h.n("rel");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("rel", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "i", {
        get: function () {
            var ret_ = this.h.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "l", {
        get: function () {
            var ret_ = this.h.n("ariaLabel");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("ariaLabel", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "c", {
        get: function () {
            var ret_ = this.h.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.h.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.h.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    ButtonBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.h.r("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.h.u("focus");
        }
    };
    ButtonBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.h.r("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.h.u("blur");
        }
    };
    ButtonBase.prototype.t = function (a) {
        this.nativeElement.focus(this.h.i(a));
    };
    ButtonBase.prototype.q = function () {
        this.nativeElement.blur();
    };
    ButtonBase.$t = markType(ButtonBase, 'ButtonBase', BaseElement.$);
    return ButtonBase;
}(BaseElement));
export { ButtonBase };
